==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/cs.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Chybí heslo klíče pro obnovu",
    "Please repeat the recovery key password" : "Zopakujte prosím heslo klíče pro obnovu",
    "Repeated recovery key password does not match the provided recovery key password" : "Zadaná hesla pro obnovu se neshodují",
    "Recovery key successfully enabled" : "Záchranný klíč byl úspěšně povolen",
    "Could not enable recovery key. Please check your recovery key password!" : "Nepodařilo se povolit záchranný klíč. Zkontrolujte prosím vaše heslo záchranného klíče!",
    "Recovery key successfully disabled" : "Záchranný klíč byl úspěšně zakázán",
    "Could not disable recovery key. Please check your recovery key password!" : "Nelze zakázat záchranný klíč. Zkontrolujte prosím heslo svého záchranného klíče!",
    "Missing parameters" : "Chybějící parametry",
    "Please provide the old recovery password" : "Zadejte prosím staré heslo pro obnovu",
    "Please provide a new recovery password" : "Zadejte prosím nové heslo pro obnovu",
    "Please repeat the new recovery password" : "Zopakujte prosím nové heslo pro obnovu",
    "Password successfully changed." : "Heslo bylo úspěšně změněno.",
    "Could not change the password. Maybe the old password was not correct." : "Změna hesla se nezdařila. Pravděpodobně nebylo stávající heslo zadáno správně.",
    "Recovery Key disabled" : "Záchranný klíč není povolen",
    "Recovery Key enabled" : "Záchranný klíč povolen",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nelze povolit záchranný klíč. Zkuste to prosím znovu nebo kontaktujte svého správce.",
    "Could not update the private key password." : "Nelze aktualizovat heslo soukromého klíče.",
    "The old password was not correct, please try again." : "Staré heslo nebylo zadáno správně, zkuste to prosím znovu.",
    "The current log-in password was not correct, please try again." : "Současné přihlašovací heslo nebylo zadáno správně, zkuste to prosím znovu.",
    "Private key password successfully updated." : "Heslo soukromého klíče úspěšně aktualizováno.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Musíte přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Spusťte příkaz 'occ encryption:migrate' nebo kontaktujte svého administrátora.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chybný soukromý klíč pro šifrovací aplikaci. Aktualizujte prosím heslo svého soukromého klíče v osobním nastavení, abyste znovu získali přístup ke svým zašifrovaným souborům.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikace pro šifrování je zapnuta, ale vaše klíče nejsou inicializované. Prosím odhlaste se a znovu přihlaste.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Chcete-li používat šifrovací modul, povolte prosím šifrování na straně serveru v nastavení administrátora.",
    "Encryption app is enabled and ready" : "Aplikace šifrování je již povolena a připravena",
    "Bad Signature" : "Špatný podpis",
    "Missing Signature" : "Chybějící podpis",
    "one-time password for server-side-encryption" : "jednorázové heslo pro šifrování na straně serveru",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tento soubor se nepodařilo dešifrovat, pravděpodobně je sdílený. Požádejte prosím majitele souboru, aby jej s vámi znovu sdílel.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Soubor nelze načíst, pravděpodobně se jedná o sdílený soubor. Požádejte prosím vlastníka souboru, aby vám jej znovu sdílel.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Ahoj!\n\nAdministrátor povolil šifrování dat na serveru. Vaše soubory byly zašifrovány za použití hesla '%s'.\n\nPřihlašte se do webového rozhraní, přejděte do nastavení 'základního šifrovacího modulu' a aktualizujte šifrovací heslo zadáním hesla výše do pole 'původní přihlašovací heslo' a svého aktuálního přihlašovacího hesla.\n\n",
    "The share will expire on %s." : "Sdílení vyprší %s.",
    "Cheers!" : "Ať slouží!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Ahoj!<br><br>Administrátor povolil šifrování dat na serveru. Vaše soubory byly zašifrovány za použití hesla <strong>%s<strong>.<br><br>Přihlašte se do webového rozhraní, přejděte do nastavení \"základního šifrovacího modulu\" a aktualizujte šifrovací heslo zadáním hesla výše do pole \"původní přihlašovací heslo\" a svého aktuálního přihlašovacího hesla.<br><br>",
    "Default encryption module" : "Výchozí šifrovací modul",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikace pro šifrování je zapnuta, ale šifrovací klíče ještě nejsou inicializované. Prosím odhlaste se a znovu se přihlaste",
    "Encrypt the home storage" : "Zašifrovat domovské úložiště",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Povolení tohoto nastavení zašifruje všechny soubory uložené v hlavním úložišti, jinak budou šifrovány pouze soubory na externích úložištích.",
    "Enable recovery key" : "Povolit záchranný klíč",
    "Disable recovery key" : "Vypnout záchranný klíč",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Záchranný klíč je dodatečný šifrovací klíč použitý pro\nšifrování souborů. S jeho pomocí lze obnovit soubory uživatele při zapomenutí hesla.",
    "Recovery key password" : "Heslo klíče pro obnovu",
    "Repeat recovery key password" : "Zopakovat heslo záchranného klíče",
    "Change recovery key password:" : "Změna hesla klíče pro obnovu:",
    "Old recovery key password" : "Staré heslo záchranného klíče",
    "New recovery key password" : "Nové heslo záchranného klíče",
    "Repeat new recovery key password" : "Zopakujte nové heslo záchranného klíče",
    "Change Password" : "Změnit heslo",
    "Basic encryption module" : "Základní šifrovací modul",
    "Your private key password no longer matches your log-in password." : "Heslo vašeho soukromého klíče se již neshoduje s vaším přihlašovacím heslem.",
    "Set your old private key password to your current log-in password:" : "Změňte své staré heslo soukromého klíče na stejné, jako je vaše současné přihlašovací heslo:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Pokud si nepamatujete své původní heslo, můžete požádat správce o obnovu vašich souborů.",
    "Old log-in password" : "Původní přihlašovací heslo",
    "Current log-in password" : "Aktuální přihlašovací heslo",
    "Update Private Key Password" : "Změnit heslo soukromého klíče",
    "Enable password recovery:" : "Povolit obnovu hesla:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Zapnutí této volby vám umožní znovu získat přístup k vašim zašifrovaným souborům pokud ztratíte heslo",
    "Enabled" : "Povoleno",
    "Disabled" : "Zakázáno"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/cs.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Chybí heslo klíče pro obnovu",
    "Please repeat the recovery key password" : "Zopakujte prosím heslo klíče pro obnovu",
    "Repeated recovery key password does not match the provided recovery key password" : "Zadaná hesla pro obnovu se neshodují",
    "Recovery key successfully enabled" : "Záchranný klíč byl úspěšně povolen",
    "Could not enable recovery key. Please check your recovery key password!" : "Nepodařilo se povolit záchranný klíč. Zkontrolujte prosím vaše heslo záchranného klíče!",
    "Recovery key successfully disabled" : "Záchranný klíč byl úspěšně zakázán",
    "Could not disable recovery key. Please check your recovery key password!" : "Nelze zakázat záchranný klíč. Zkontrolujte prosím heslo svého záchranného klíče!",
    "Missing parameters" : "Chybějící parametry",
    "Please provide the old recovery password" : "Zadejte prosím staré heslo pro obnovu",
    "Please provide a new recovery password" : "Zadejte prosím nové heslo pro obnovu",
    "Please repeat the new recovery password" : "Zopakujte prosím nové heslo pro obnovu",
    "Password successfully changed." : "Heslo bylo úspěšně změněno.",
    "Could not change the password. Maybe the old password was not correct." : "Změna hesla se nezdařila. Pravděpodobně nebylo stávající heslo zadáno správně.",
    "Recovery Key disabled" : "Záchranný klíč není povolen",
    "Recovery Key enabled" : "Záchranný klíč povolen",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nelze povolit záchranný klíč. Zkuste to prosím znovu nebo kontaktujte svého správce.",
    "Could not update the private key password." : "Nelze aktualizovat heslo soukromého klíče.",
    "The old password was not correct, please try again." : "Staré heslo nebylo zadáno správně, zkuste to prosím znovu.",
    "The current log-in password was not correct, please try again." : "Současné přihlašovací heslo nebylo zadáno správně, zkuste to prosím znovu.",
    "Private key password successfully updated." : "Heslo soukromého klíče úspěšně aktualizováno.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chybný soukromý klíč pro šifrovací aplikaci. Aktualizujte prosím heslo svého soukromého klíče v osobním nastavení, abyste znovu získali přístup ke svým zašifrovaným souborům.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikace pro šifrování je zapnuta, ale vaše klíče nejsou inicializované. Prosím odhlaste se a znovu přihlaste.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Chcete-li používat šifrovací modul, povolte prosím šifrování na straně serveru v nastavení administrátora.",
    "Encryption app is enabled and ready" : "Aplikace šifrování je již povolena a připravena",
    "Bad Signature" : "Špatný podpis",
    "Missing Signature" : "Chybějící podpis",
    "one-time password for server-side-encryption" : "jednorázové heslo pro šifrování na straně serveru",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tento soubor se nepodařilo dešifrovat, pravděpodobně je sdílený. Požádejte prosím majitele souboru, aby jej s vámi znovu sdílel.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Soubor nelze načíst, pravděpodobně se jedná o sdílený soubor. Požádejte prosím vlastníka souboru, aby vám jej znovu sdílel.",
    "Default encryption module" : "Výchozí šifrovací modul",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Ahoj!\n\nAdministrátor povolil šifrování dat na serveru. Vaše soubory byly zašifrovány za použití hesla '%s'.\n\nPřihlašte se do webového rozhraní, přejděte do nastavení 'základního šifrovacího modulu' a aktualizujte šifrovací heslo zadáním hesla výše do pole 'původní přihlašovací heslo' a svého aktuálního přihlašovacího hesla.\n\n",
    "The share will expire on %s." : "Sdílení vyprší %s.",
    "Cheers!" : "Ať slouží!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Ahoj!<br><br>Administrátor povolil šifrování dat na serveru. Vaše soubory byly zašifrovány za použití hesla <strong>%s<strong>.<br><br>Přihlašte se do webového rozhraní, přejděte do nastavení \"základního šifrovacího modulu\" a aktualizujte šifrovací heslo zadáním hesla výše do pole \"původní přihlašovací heslo\" a svého aktuálního přihlašovacího hesla.<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikace pro šifrování je zapnuta, ale šifrovací klíče ještě nejsou inicializované. Prosím odhlaste se a znovu se přihlaste",
    "Encrypt the home storage" : "Zašifrovat domovské úložiště",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Povolení tohoto nastavení zašifruje všechny soubory uložené v hlavním úložišti, jinak budou šifrovány pouze soubory na externích úložištích.",
    "Enable recovery key" : "Povolit záchranný klíč",
    "Disable recovery key" : "Vypnout záchranný klíč",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Záchranný klíč je dodatečný šifrovací klíč použitý pro\nšifrování souborů. S jeho pomocí lze obnovit soubory uživatele při zapomenutí hesla.",
    "Recovery key password" : "Heslo klíče pro obnovu",
    "Repeat recovery key password" : "Zopakovat heslo záchranného klíče",
    "Change recovery key password:" : "Změna hesla klíče pro obnovu:",
    "Old recovery key password" : "Staré heslo záchranného klíče",
    "New recovery key password" : "Nové heslo záchranného klíče",
    "Repeat new recovery key password" : "Zopakujte nové heslo záchranného klíče",
    "Change Password" : "Změnit heslo",
    "Basic encryption module" : "Základní šifrovací modul",
    "Your private key password no longer matches your log-in password." : "Heslo vašeho soukromého klíče se již neshoduje s vaším přihlašovacím heslem.",
    "Set your old private key password to your current log-in password:" : "Změňte své staré heslo soukromého klíče na stejné, jako je vaše současné přihlašovací heslo:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Pokud si nepamatujete své původní heslo, můžete požádat správce o obnovu vašich souborů.",
    "Old log-in password" : "Původní přihlašovací heslo",
    "Current log-in password" : "Aktuální přihlašovací heslo",
    "Update Private Key Password" : "Změnit heslo soukromého klíče",
    "Enable password recovery:" : "Povolit obnovu hesla:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Zapnutí této volby vám umožní znovu získat přístup k vašim zašifrovaným souborům pokud ztratíte heslo",
    "Enabled" : "Povoleno",
    "Disabled" : "Zakázáno",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Musíte přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Spusťte příkaz 'occ encryption:migrate' nebo kontaktujte svého administrátora."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
